﻿Sys.UI.InPlaceEditingInput = function(associatedElement) {
    Sys.UI.InPlaceEditingInput.initializeBase(this, [associatedElement]);
    
    var _labelColor = "white";
    var _inputBorderColor = "black";
    var _inputBgColor = "#f2f2f9";
    var _toolTipText;
    var _toolTipTextColor = "#aaa";
    
    var _isEditing = false;
    
    var _mouseOverHandler;
    var _mouseOutHandler;
    var _focusHandler;
    var _blurHandler;
    
    this.get_toolTipText = function() {
        return _toolTipText;
    }
    this.set_toolTipText = function(value) {
        if (_toolTipText != value) {
            _toolTipText = value;
            this.element.value = _toolTipText;
            this.raisePropertyChanged('toolTipText');
        }
    }
    this.get_labelColor = function() {
        return _labelColor;
    }
    this.set_labelColor = function(value) {
        if (_labelColor != value) {
            _labelColor = value;
            this.raisePropertyChanged('labelColor');
        }
    }
    this.get_inputBorderColor = function() {
        return _inputBorderColor;
    }
    this.set_inputBorderColor = function(value) {
        if (_inputBorderColor != value) {
            _inputBorderColor = value;
            this.raisePropertyChanged('inputBorderColor');
        }
    }
    this.get_inputBorderColor = function() {
        return _inputBorderColor;
    }
    this.set_inputBgColor = function(value) {
        if (_inputBgColor != value) {
            _inputBgColor = value;
            this.raisePropertyChanged('inputBgColor');
        }
    }
    this.get_toolTipTextColor = function() {
        return _toolTipTextColor;
    }
    this.set_toolTipTextColor = function(value) {
        if (_toolTipTextColor != value) {
            _toolTipTextColor = value;
            this.raisePropertyChanged('toolTipTextColor');
        }
    }
    
    this.initialize = function() {
        Sys.UI.InPlaceEditingInput.callBaseMethod(this, 'initialize');

        _mouseOverHandler = Function.createDelegate(this, this._onMouseOver);
        this.element.attachEvent('onmouseover', _mouseOverHandler);
        
        _mouseOutHandler = Function.createDelegate(this, this._onMouseOut);
        this.element.attachEvent('onmouseout', _mouseOutHandler);
        
        _focusHandler = Function.createDelegate(this, this._onFocus);
        this.element.attachEvent('onfocus', _focusHandler);
        
        _blurHandler = Function.createDelegate(this, this._onBlur);
        this.element.attachEvent('onblur', _blurHandler);
        
        this._onMouseOut();
        this.element.style.color = _toolTipTextColor;
    }

    this.dispose = function() {
        if (_mouseOverHandler) {
            this.element.detachEvent('onmouseover', _mouseOverHandler);
            _mouseOverHandler = null;
        }
        if (_mouseOutHandler) {
            this.element.detachEvent('onmouseout', _mouseOutHandler);
            _mouseOutHandler = null;
        }
        if (_focusHandler) {
            this.element.detachEvent('onfocus', _focusHandler);
            _focusHandler = null;
        }
        if (_blurHandler) {
            this.element.detachEvent('onblur', _blurHandler);
            _blurHandler = null;
        }
        
        Sys.UI.InPlaceEditingInput.callBaseMethod(this, 'dispose');
    }

    this.getDescriptor = function() {
        var td = Sys.UI.InPlaceEditingInput.callBaseMethod(this, 'getDescriptor');
        
        td.addProperty('toolTipText', String);
        td.addProperty('labelColor', String);
        td.addProperty('inputBorderColor', String);
        td.addProperty('toolTipText', String);
        td.addProperty('inputBgColor', String);
        return td;
    }
    Sys.UI.InPlaceEditingInput.registerBaseMethod(this, 'getDescriptor');
    
    this._onMouseOver = function() {
        if (!_isEditing) {
            this.element.style.border = "1px solid " + _inputBorderColor;
            this.element.style.backgroundColor = _labelColor;
        }
    }
    this._onMouseOut = function() {
        if (!_isEditing) {
            this.element.style.border = "1px solid " + _labelColor;
            this.element.style.backgroundColor = _labelColor;
        }
    }
    this._onFocus = function() {
        if (!_isEditing) {
            this.element.style.border = "1px solid " + _inputBorderColor;
            this.element.style.backgroundColor = _inputBgColor;
            if (_toolTipText == this.element.value) {
                this.element.value = "";
                this.element.style.color = "";
            }
            _isEditing = true;
        }
    }
    this._onBlur = function() {
        if (_isEditing) {
            this.element.style.border = "1px solid " + _labelColor;
            this.element.style.backgroundColor = _labelColor;
            if ("" == this.element.value) {
                this.element.value = _toolTipText;
                this.element.style.color = _toolTipTextColor;
            }
            _isEditing = false;
        }
    }
}
Sys.UI.InPlaceEditingInput.registerClass('Sys.UI.InPlaceEditingInput', Sys.UI.TextBox);
Sys.TypeDescriptor.addType('script', 'inPlaceEditingInput', Sys.UI.InPlaceEditingInput);